@@ -13,7 +13,7 @@ use Rose::DB::Object::Constants
 
 use Rose::DB::Object::Util qw(column_value_formatted_key);
 
-our $VERSION = '0.74';
+our $VERSION = '0.752';
 
 sub interval
 {
@@ -456,13 +456,13 @@ Rose::DB::Object::MakeMethods::Time - Create time-related methods for Rose::DB::
     (
       interval => 
       [
-        t1 => { precision => 6 },
+        t1 => { scale => 6 },
         t2 => { default => '3 days 6 minutes 5 seconds' },
       ],
 
       time =>
       [
-        start => { precision => 5 },
+        start => { scale => 5 },
         end   => { default => '12:34:56' },
       ],
     );
@@ -531,7 +531,7 @@ attribute.  Defaults to the name of the method.
 
 Choose the interface.  The default is C<get_set>.
 
-=item C<precision>
+=item C<scale>
 
 An integer number of places past the decimal point preserved for fractional seconds.  Defaults to 0.
 
@@ -572,7 +572,7 @@ Example:
     (
       time => 
       [
-        't1' => { precision => 6 },
+        't1' => { scale => 6 },
         't2' => { default => '3 days 6 minutes 5 seconds' },
       ],
     );
@@ -609,7 +609,7 @@ attribute.  Defaults to the name of the method.
 
 Choose the interface.  The default is C<get_set>.
 
-=item C<precision>
+=item C<scale>
 
 An integer number of places past the decimal point preserved for fractional seconds.  Defaults to 0.  The maximum value is 9.
 
@@ -649,7 +649,7 @@ Example:
     (
       time =>
       [
-        start => { precision => 5 },
+        start => { scale => 5 },
         end   => { default => '12:34:56' },
       ],
     );
@@ -680,6 +680,6 @@ John C. Siracusa (siracusa@mindspring.com)
 
 =head1 COPYRIGHT
 
-Copyright (c) 2006 by John C. Siracusa.  All rights reserved.  This program is
+Copyright (c) 2007 by John C. Siracusa.  All rights reserved.  This program is
 free software; you can redistribute it and/or modify it under the same terms
 as Perl itself.
