@@ -7,7 +7,7 @@ use Rose::DB::Object::MakeMethods::BigNum;
 use Rose::DB::Object::Metadata::Column::Integer;
 our @ISA = qw(Rose::DB::Object::Metadata::Column::Integer);
 
-our $VERSION = '0.711';
+our $VERSION = '0.757';
 
 INIT_METHOD_MAKER_INFO:
 {
@@ -50,6 +50,12 @@ INIT_METHOD_MAKER_INFO:
 
 sub type { 'bigint' }
 
+sub format_value
+{
+  my($self, $db, $value) = @_;
+  return ref $value ? $value->bstr : $value;
+}
+
 1;
 
 __END__
@@ -128,6 +134,6 @@ John C. Siracusa (siracusa@mindspring.com)
 
 =head1 COPYRIGHT
 
-Copyright (c) 2006 by John C. Siracusa.  All rights reserved.  This program is
+Copyright (c) 2007 by John C. Siracusa.  All rights reserved.  This program is
 free software; you can redistribute it and/or modify it under the same terms
 as Perl itself.
