@@ -11,7 +11,7 @@ our @ISA = qw(Exporter);
 
 our @EXPORT_OK = qw(build_select build_where_clause);
 
-our $VERSION = '0.757';
+our $VERSION = '0.759';
 
 our $Debug = 0;
 
@@ -59,28 +59,35 @@ sub build_select
 {
   my(%args) = @_;
 
-  my $dbh         = $args{'dbh'};
-  my $tables      = $args{'tables'} || Carp::croak "Missing 'tables' argument";
-  my $tables_sql  = $args{'tables_sql'} || $tables;
-  my $logic       = delete $args{'logic'} || 'AND';
-  my $columns     = $args{'columns'};  
-  my $all_columns = $args{'all_columns'} || {};
-  my $query_arg   = delete $args{'query'};
-  my $sort_by     = delete $args{'sort_by'};
-  my $group_by    = delete $args{'group_by'};
-  my $limit       = delete $args{'limit'};
-  my $distinct    = delete $args{'distinct'} ? 'DISTINCT ' : '';
-  my $select      = $args{'select'};
-  my $where_only  = delete $args{'where_only'};
-  my $clauses_arg = delete $args{'clauses'};  
-  my $pretty      = exists $args{'pretty'} ? $args{'pretty'} : $Debug;
-  my $joins       = $args{'joins'};
-  my $hints       = $args{'hints'} || {};
-  my $set         = delete $args{'set'};
-  my $table_map   = delete $args{'table_map'} || {};
-  my $bind_params = $args{'bind_params'};
+  my $dbh          = $args{'dbh'};
+  my $tables       = $args{'tables'} || Carp::croak "Missing 'tables' argument";
+  my $tables_sql   = $args{'tables_sql'} || $tables;
+  my $logic        = delete $args{'logic'} || 'AND';
+  my $columns      = $args{'columns'};  
+  my $all_columns  = $args{'all_columns'} || {};
+  my $query_arg    = delete $args{'query'};
+  my $sort_by      = delete $args{'sort_by'};
+  my $group_by     = delete $args{'group_by'};
+  my $limit_suffix = delete $args{'limit_suffix'};
+  my $limit_prefix = delete $args{'limit_prefix'} || '';
+  my $distinct     = delete $args{'distinct'} ? 'DISTINCT ' : '';
+  my $select       = $args{'select'};
+  my $where_only   = delete $args{'where_only'};
+  my $clauses_arg  = delete $args{'clauses'};  
+  my $pretty       = exists $args{'pretty'} ? $args{'pretty'} : $Debug;
+  my $joins        = $args{'joins'};
+  my $hints        = $args{'hints'} || {};
+  my $set          = delete $args{'set'};
+  my $table_map    = delete $args{'table_map'} || {};
+  my $bind_params  = $args{'bind_params'};
   my $from_and_where_only = delete $args{'from_and_where_only'};
   my $allow_empty_lists   = $args{'allow_empty_lists'};
+  my $unique_aliases = $args{'unique_aliases'};
+
+  if($args{'limit'})
+  {
+    $limit_suffix = 'LIMIT ' . delete $args{'limit'};
+  }
 
   $all_columns = $columns  unless(%$all_columns);
 
@@ -258,6 +265,14 @@ sub build_select
       my $rel_column    =  $table_map->{$table_tn} ?
         "$table_map->{$table_tn}.$column" : '';
 
+      my $fq_column_trimmed;
+      
+      TRIM:
+      {
+        (my $t = $table) =~ s/^[^.]+\.//;
+        $fq_column_trimmed = "$t.$column";
+      }
+      
       # Avoid duplicate clauses if the table name matches the relationship name
       $rel_column = ''  if($rel_column eq $fq_column);
 
@@ -268,11 +283,17 @@ sub build_select
         if($multi_table)
         {
           push(@select_columns, 
-            $obj_meta ? ($obj_meta->column($column)->select_sql($db, $table_alias) . 
-                         ' AS ' . $db->auto_quote_column_name("${table_alias}_$column")) :
-            $db ? ($db->auto_quote_column_with_table($column, $table_alias) . 
-                   ' AS ' . $db->auto_quote_column_name("${table_alias}_$column")) :
-            "$short_column AS ${table_alias}_$column");
+            $obj_meta ? 
+            (
+              $obj_meta->column($column)->select_sql($db, $table_alias) . 
+              ($unique_aliases ? (' AS ' . $db->auto_quote_column_name("${table_alias}_$column")) : '')
+            ) :
+            $db ?
+            (
+              $db->auto_quote_column_with_table($column, $table_alias) . 
+              ($unique_aliases ? (' AS ' . $db->auto_quote_column_name("${table_alias}_$column")) : '')
+            ) :
+            ($unique_aliases ? "$short_column AS ${table_alias}_$column" : $short_column));
         }
         else
         {
@@ -283,7 +304,8 @@ sub build_select
       }
 
       foreach my $column_arg (grep { exists $query{$_} } map { ($_, "!$_") } 
-                              ($column, $fq_column, $short_column, $rel_column, $unique_column, 
+                              ($column, $fq_column, $fq_column_trimmed, $short_column,
+                               $rel_column, $unique_column, 
                               (defined $method && $method ne $column ? $method : ())))
       {
         $not = (index($column_arg, '!') == 0) ? 'NOT' : '';
@@ -404,8 +426,6 @@ sub build_select
 
   my $qs;
 
-  my $use_prefix_limit = $dbh->{'Driver'}{'Name'} eq 'Informix' ? 1 : 0;
-
   if(!$where_only)
   {
     my $from_tables_sql;
@@ -543,7 +563,6 @@ sub build_select
       }
     }
 
-    my $prefix_limit = (defined $limit && $use_prefix_limit) ? "$limit " : '';
     $select ||= join(",\n", map { "  $_" } @select_columns);
 
     if($from_and_where_only)
@@ -552,7 +571,14 @@ sub build_select
     }
     else
     {
-      $qs = "SELECT $prefix_limit$distinct\n$select\nFROM\n$from_tables_sql\n";
+      if($limit_prefix !~ /^SELECT /)
+      {
+        $qs = "SELECT $limit_prefix$distinct\n$select\nFROM\n$from_tables_sql\n";
+      }
+      else
+      {
+        $qs = "${limit_prefix}SELECT$distinct\n$select\nFROM\n$from_tables_sql\n";
+      }
     }
   }
 
@@ -570,7 +596,7 @@ sub build_select
 
   $qs .= "\nGROUP BY " . $group_by if($group_by);
   $qs .= "\nORDER BY " . $sort_by  if($sort_by);
-  $qs .= "\nLIMIT "    . $limit    if(defined $limit && !$use_prefix_limit);
+  $qs .= "\n" . $limit_suffix      if(defined $limit_suffix);
 
   $Debug && warn "$qs\n";
 
@@ -1099,7 +1125,7 @@ A fully formed SQL "GROUP BY ..." clause, sans the words "GROUP BY", or a refere
 
 =item B<limit NUMBER>
 
-A number to use in the "LIMIT ..." (or "FIRST ...") clause.
+A number to use in the "LIMIT ..." clause.
 
 =item B<logic LOGIC>
 
@@ -1109,42 +1135,6 @@ A string indicating the logic that will be used to join the statements in the WH
 
 If true, the SQL returned will have slightly nicer formatting.
 
-=item B<select COLUMNS>
-
-The names of the columns to select from the table.  COLUMNS may be a string of comma-separated column names, or a reference to an array of column names.  If this parameter is omitted, it defaults to all of the columns in all of the tables participating in the query (according to the value of the C<columns> argument).
-
-=item B<sort_by CLAUSE>
-
-A fully formed SQL "ORDER BY ..." clause, sans the words "ORDER BY", or a reference to an array of strings to be joined with a comma and appended to the "ORDER BY" clause.
-
-=item B<tables TABLES>
-
-A reference to an array of table names.  This argument is required.  A fatal error will occur if it is omitted.
-
-If more than one table is in the list, then each table is aliased to "tN", where N is an ascending number starting with 1.  The tables are numbered according to their order in TABLES.  Example:
-
-    $sql = build_select(tables => [ 'foo', 'bar', 'baz' ], ...);
-
-    print $sql;
-
-    # SELECT ... FROM
-    #   foo AS t1,
-    #   bar AS t2,
-    #   baz AS t3
-    # ...
-
-Furthermore, if there is no explicit value for the C<select> parameter, then each selected column is aliased with a "tN_" prefix in a multi-table query.  Example:
-
-    SELECT
-      t1.id    AS t1_id,
-      t1.name  AS t1_name,
-      t2.id    AS t2_id,
-      t2.name  AS t2_name
-    FROM
-      foo AS t1,
-      bar AS t2
-    WHERE
-      ...
 
 =item B<query PARAMS>
 
@@ -1460,13 +1450,13 @@ Finally, here's an example using more than one table:
 The above returns an SQL statement something like this:
 
     SELECT
-      t1.id          AS t1_id,
-      t1.name        AS t1_name,
-      t1.category_id AS t1_category_id,
-      t1.date        AS t1_date,
-      t2.id          AS t2_id,
-      t2.name        AS t2_name,
-      t2.description AS t2_description
+      t1.id,
+      t1.name,
+      t1.category_id,
+      t1.date,
+      t2.id,
+      t2.name,
+      t2.description
     FROM
       articles   t1,
       categories t2
@@ -1523,6 +1513,49 @@ The disadvantage is that all of this parsing and formatting is done for every qu
 
 Usually, this overhead is dwarfed by the time required for the database to service the query, and, perhaps more importantly, the reduced maintenance headache and busywork required to properly format all query values.
 
+=item B<select COLUMNS>
+
+The names of the columns to select from the table.  COLUMNS may be a string of comma-separated column names, or a reference to an array of column names.  If this parameter is omitted, it defaults to all of the columns in all of the tables participating in the query (according to the value of the C<columns> argument).
+
+=item B<sort_by CLAUSE>
+
+A fully formed SQL "ORDER BY ..." clause, sans the words "ORDER BY", or a reference to an array of strings to be joined with a comma and appended to the "ORDER BY" clause.
+
+=item B<tables TABLES>
+
+A reference to an array of table names.  This argument is required.  A fatal error will occur if it is omitted.
+
+If more than one table is in the list, then each table is aliased to "tN", where N is an ascending number starting with 1.  The tables are numbered according to their order in TABLES.  Example:
+
+    $sql = build_select(tables => [ 'foo', 'bar', 'baz' ], ...);
+
+    print $sql;
+
+    # SELECT ... FROM
+    #   foo AS t1,
+    #   bar AS t2,
+    #   baz AS t3
+    # ...
+
+Furthermore, if there is no explicit value for the C<select> parameter and if the C<unique_aliases> parameter is set to true, then each selected column is aliased with a "tN_" prefix in a multi-table query.  Example:
+
+    SELECT
+      t1.id    AS t1_id,
+      t1.name  AS t1_name,
+      t2.id    AS t2_id,
+      t2.name  AS t2_name
+    FROM
+      foo AS t1,
+      bar AS t2
+    WHERE
+      ...
+
+These unique aliases provide a technique of last resort for unambiguously addressing a column in a query clause.
+
+=item C<unique_aliases BOOL>
+
+If true, then each selected column will be given a unique alias by prefixing it with its table alias and an underscore.  The default value is false.  See the documentation for the C<tables> parameter above for an example.
+
 =back
 
 =item B<build_where_clause PARAMS>
@@ -1537,6 +1570,6 @@ John C. Siracusa (siracusa@mindspring.com)
 
 =head1 COPYRIGHT
 
-Copyright (c) 2006 by John C. Siracusa.  All rights reserved.  This program is
+Copyright (c) 2007 by John C. Siracusa.  All rights reserved.  This program is
 free software; you can redistribute it and/or modify it under the same terms
 as Perl itself.
